@@ -76,6 +76,7 @@ class Config:
     def ffmpeg_hls(self):
         return self._get_value("ffmpeg_hls", False, bool)
 
+    
     @property
     def ffmpeg_log_path(self):
         return self.user_files_path / "ffmpeg_log"
@@ -94,6 +95,10 @@ class Config:
     def dc_presence(self):
         return self._get_value("dc_presence", False, bool)
 
+    @property
+    def auto_open_dl_defaultcli(self):
+        return self._get_value("auto_open_dl_defaultcli", False, bool)
+
     def _get_path_value(self, key: str, fallback: Path) -> Path:
         path = self._get_value(key, fallback, str)
         try:
